id stringlengths 5 11 | text stringlengths 0 146k | title stringclasses 1
value |
|---|---|---|
doc_23508900 | 04-12 19:28:36.194 21114-21114/com.dsgn.bbup E/AndroidRuntime﹕ FATAL EXCEPTION: main
Process: com.dsgn.bbup, PID: 21114
java.lang.RuntimeException: Unable to start activity ComponentInfo{com.dsgn.bbup/com.wlodsgn.bunbunup.JeansActivity}: java.lang.NullPointerException
at android.app.ActivityThread.... | |
doc_23508901 | My JSON string :
[
{ "EmpId": 1, "Name": "Simone", "City": "Italy" },
{ "EmpId": 2, "Name": "Luca", "City": "Francia" },
{ "EmpId": 1, "Name": "Matteo", "City": "Inghilterra"},
{ "EmpId": 2, "Name": "Marco", "City": "Spagna" }
]
My ReturnClass :
public class ReturnClass
{
public int EmpId { get;... | |
doc_23508902 | $ git gc
$ git filter-repo --replace-refs delete-no-add --strip-blobs-bigger-than $ 10M
$ git reflog expire --expire=now --all
$ git gc --aggressive --prune=now
$ git commit
$ git push origin master --force
du -sh .git returns 2 GB before and 25 MB after the operation, but the size on bitbucket remains 2GB
when I git ... | |
doc_23508903 | Im trying to retrieve info from my form and add it all together in line 82
Form:
<!DOCTYPE HTML>
<html>
<head>
<style>
.error {color: #FF0000;}
</style>
</head>
<body> <form method="POST" action="gc.php">
Interceptors:<input type="text" name="inter" value="<?php echo $inter;?>"><br><br>
Destroyers:<input type="text" ... | |
doc_23508904 | <div class="wrapper1">
<div class="object obj1"></div>
<div class="wrapper2">
<div class="object obj2"></div>
<div class="object obj3"></div>
</div>
</div>
Wrapper1 is 100% wide with centered content.
Now I want the following scenario.
*
*When screen is wide enough, the three boxes must be arranged i... | |
doc_23508905 | import numpy as np
import pandas as pd
arrays = [['Apple','Apple','Banana','Banana','Cherry','Cherry'],
['one', 'two', 'one', 'two', 'one', 'two', 'one', 'two']]
tuples = list(zip(*arrays))
index = pd.MultiIndex.from_tuples(tuples, names=['first', 'second'])
df = pd.DataFrame(np.zeros([3, 6]), index=['A', 'B',... | |
doc_23508906 |
Any ideas on how to write the code?
I've tried
.column {
@include span-columns(1);
@include omega(2n)
}
but all columns have the same height. And I need different heights.
Thank you in advance.
A: To get this:
Your html needs to look about like this:
<div class = 'content'>
<div class = 'short-column' id ='r... | |
doc_23508907 |
A: There are multiple applications in Oracle ERP based on different underlying technologies, at least:
*
*Oracle Forms (no)
*Oracle Siebel (yes)
*Oracle JD Edwards (yes)
*Oracle People Soft (yes)
*Oracle Hyperion Financial Management (yes)
*Oracle ADF (yes)
For those marked (yes) , it is possible since it's ... | |
doc_23508908 |
A: <script language="JavaScript">
function validate()
{
var dateEntered = new Date( document.getElementById("Date") + " " + document.getElementById("Time") );
var dateNow = new Date();
if( dateNow - dateEntered > 1000*60*60*12 )
{
alert( "Date entered is too old." );
return( false );
... | |
doc_23508909 | Here is my array of data:
fields: [{
type_one: "text",
label_one: "First Name",
model_one: "",
required_one: true,
rules_one: [
v => !!v || 'First name is required',
],
type_two: "text",
label_two: "Last Name... | |
doc_23508910 | The file:
// The range of 'horizontal' indices, inclusive
// E.g. if the range is 0-4, then the indices are 0, 1, 2, 3, 4
GridX_IdxRange=0-8
// The range of 'vertical' indices, inclusive
// E.g. if the range is 0-3, then the indices are 0, 1, 2, 3
GridY_IdxRange=0-8
// [x,y] grid-areas which are occupied by cities
ci... | |
doc_23508911 | Blender Settings:
*
*Frame rate: 30
*Codec: h.264
*Output .mp4
*Keyframe interval: 1
*Output quality: Medium
*Encoding speed: Good
Here's my current command however the seeking and file size is different:
ffmpeg -framerate 30 -i %04d.jpg -g 1 -vcodec libx264 video.mp4
A: ffmpeg -r 30 -i %04d.jpg -vcodec libx26... | |
doc_23508912 | Currently I'm trying to get news topic from main page of Yahoo Japan. but it return nil.
NSStringEncoding UTF = 4;
NSString *htmlWillInsert = [NSString stringWithContentsOfURL:[NSURL URLWithString:@"http://www.yahoo.co.jp/"] encoding:UTF error:nil];
NSData *htmlData = [htmlWillInsert dataUsingEncoding:NSUnicodeStringE... | |
doc_23508913 | For example, a user is removing a 'kit' which consists of 6 parts. But the user doesnt realise that one of the parts is already at 0. then when they press the button the other parts decrease by one.
How can i prevent this?
A: When they select the part/kit you need to query the database to verify the part(s) are availa... | |
doc_23508914 |
and this is the graph:
const graphHighs = {
pk: series.pk,
lineColor: series.seriesMetaData.colorHex,
lineThickness: series.graph.thickness,
valueField: `${series.pk.uuid}${series.seriesMetaData.reportType}-highs`,
valueAxis: series.seriesMetaData.unitOfMeasurement,
lineAlpha: series.graph.opacity,
type:... | |
doc_23508915 | public async Task<List<User>> GetCollection()
{
List<User> result = _identityContext.Users
.GroupJoin(
_identityContext.UserClaims,
u => u.Id,
uc => uc.UserId,
(u, uc) => new { user = u, claims = uc })
.ToList()
.Select(u => new User(
... | |
doc_23508916 | #include<iostream>
class Stuff {};
ostream &operator<<(ostream &lhs, const Stuff &rhs) {
return lhs << "something";
}
int main() {
Stuff stuff;
cout << stuff << endl;
cin.get();
}
where the operator<< function prints the mockup Stuff class to an ostream. What I would like to do though is move that ... | |
doc_23508917 | How can I do this?
I tried with Bat to Exe, but doesn't work since I have JScript.
The code is basically launching a site and entering key inputs, and the .exe manages to launch the site, but that's it
Script:
@if (@CodeSection == @Batch) @then
@echo off
title Top Top
color 0c
if "%inputParty%" == "0" (
set title... | |
doc_23508918 | I've been given a series of files to do a data conversion and would like to migrate the provided data into SQL Server 2008. The files are:
*
**.myd
**.myi
**.frm
These file types, as I understand it, are MyISAM. I believe that if I had a running MySQL instance, migrating to SQL Server would be fairly straightf... | |
doc_23508919 | <nav class="navbar navbar-default navbar-fixed-top navbar-header-full">
<div class="header-full-title img-responsive">
<img src="~/Content/img/MTC_logo_header.png" class="img-responsive" />
</div>
<div id="navbar" class="navbar-collapse">
<div class="navbar-head... | |
doc_23508920 | I use as database a GCP CloudSQL with postgres 9.6
When trying to execute the create_db script from the redash image (7.0.0.b18042) I encounter the following error
Traceback (most recent call last):
File "/app/manage.py", line 9, in <module>
manager()
File "/usr/local/lib/python2.7/dist-packages/click/core.p... | |
doc_23508921 | [('tags', 'int'),
('user_id', 'bigint'),
('processdate', 'date'),
('brandsurvey_name', 'string'),
('survey_id', 'string'),
('questionid', 'string'),
('questiontext', 'string'),
('frequency', 'bigint'),
('creative_id', 'string')]
When i use fillna(0) then some values of user_id column is getting corrupt... | |
doc_23508922 | >>> from django.contrib.auth import authenticate
>>> user = authenticate(username='shiva@gmail.com',password='123456')
>>> user
<Employee: shiva@gmail.com>
>>>
but I am not able login using the url : http://localhost:8000/admin/login/?next=/admin/
showing following error:
Please enter the correct email address and p... | |
doc_23508923 | SELECT
b.building_id,
b.building_name,
b.street_number,
b.street_name,
ARRAY(b.floor_id)floor_ids
FROM
building b
WHERE
b.monitored_status = 'monitored'
GROUP BY
b.building_id
| |
doc_23508924 |
I got Jack Dawson as name.
Now I want to split it from the place where it contains space. i.e.
*
*First name : Jack
*Last name : Dawson
A: Say for example the string is "Jack Dawson".
Now, if you want to split it with spaces,
String currentString = "Jack Dawson";
String[] separated = currentString.split(" ");
T... | |
doc_23508925 |
A: Every GameObject in Unity has a Transform component attached to it. This can be accessed from other components using
Transform trans = gameObject.transform
This component has properties that can be used to alter the object's transformation. Among them are e.g.
position (Vector3)
rotation (Quaternion)
eulerAngles... | |
doc_23508926 | public class User :IdentityUser
{
public string Name { get; set; }
public string SecondName { get; set; }
public string Country { get; set; }
public int? Age { get; set; }
public string Picture { get; set; }
public DateTime DateAdded { get; set; }
}
from v... | |
doc_23508927 | Vertical drag and drop works perfectly, but I can't get an item in the column to drag horizontally within that column, i.e. change its outline rank. Will I have to track the mouse and programmatically change the rank?
Thanks
A: OK. I just discovered that an item can be dropped on the top of another item and that wil... | |
doc_23508928 | <div>
{% crispy comment_form comment_form.helper %}
</div>
<script>
$(document).ready(function() {
$(document).on('submit', 'form', function(e){
e.preventDefault();
if($(this).parents("tr").length != 0) {
parent_id = $(this).parents("tr").attr("id").spli... | |
doc_23508929 | for example
f(list<tuple<u,v>>) => tuple<list<u>,list<v>>
This use case does not appear to be accommodated well by the standard API.
Other articles say to use reduce, but this does not work since it will only return the same type as the input type.
In .net I would use Enumerable.Aggregate to achieve this.
Is there a fu... | |
doc_23508930 | "Unable to parse template "Class"
Error message: Cannot modify a read-only directory 'C:\Users\======\AppData\Local\Android\sdk\platforms\android-21\android.jar!\android\database\sqlite'."
this happens when I try to create a java class with "SQLiteOpenHelper"
| |
doc_23508931 | Incase it's not clear, primepoint is the pointer that's incremented when checking for prime numbers, primesqr is the squareroot of primepoint (since that's the highest value you need to check for) and primearray is where the primes are meant to be stored.
Thanks!
//Number being checked
var primepoint = 2;
//Sqr of ... | |
doc_23508932 | I tried to set it like this:
class LineChart extends Component {
datasetKeyProvider() {
return Math.random();
}
render() {
return (
<>
<Line
data={this.state.chartData}
datasetKeyProvider={this.datasetKeyProvider}
options={{
legend: {
display: true,
posit... | |
doc_23508933 | $a = null;
var_dump(isset($a)); // false
How do I just check if a variable is set if isset is not the one I am after?
I can't use empty, for example,
var_dump(empty($b)); // false
But $b is not set at all.
I can do that in javascript which makes more sense,
if (typeof variable !== 'undefined') ...
A: isset checks ... | |
doc_23508934 | How to fix this?
Please guide me.
when I print the timeMinute System.out: 30 am I get an
error on this line Integer.parseInt(timeMinute.replace(" am","")), true);
start_time.setInputType(InputType.TYPE_NULL);
start_time.setOnClickListener(new View.OnClickListener() {
@Override
pub... | |
doc_23508935 |
PG::StringDataRightTruncation: ERROR: value too long for type character varying(255) : UPDATE "listings" SET "created_at" = $1, "date_posted" = $2, "google_map_link" = $3, "phone" = $4, "acency_id" = $5, "updated_at" = $6 WHERE "listings"."id" = 392998
A: I work almost exclusively with large numbers of text files in... | |
doc_23508936 | An example of this would be:
file1
apple green 4
orange red 5
apple yellow 6
apple yellow 8
grape green 5
file2
apple yellow 7
grape green 10
output
apple green 4
orange red 5
apple yellow 8
I want to remove lines where $1 and $2 from file1 correspond to $1 and $2 from file2 AND when $3 from file1 is s... | |
doc_23508937 | intellisense after I press ctrl + space: enter image description here
I upgraded to vs code version 1.11.0 and opened my project. When I try to use import statement in the code, code completion is not working for installed node modules until I press ctr + space. But previously (before upgrade) when I start type the no... | |
doc_23508938 | I would like to handle failed api requests in a similar way to how I handle the successful api requests. Yet as far as I can tell, the SEARCH_FAILURE FSA never gets handled, though it is treated (AFAICT) identically to the SEARCH_SUCCESS FSA. It does seem to be created and dispatched, based on what I see in the devtool... | |
doc_23508939 | But I don't want to display a guid. In another table BizV the name for each guid are stored. As the image below.
How do I change the code so that from the listing it will get the shortdesc and pass back tolist();
[WebMethod]
public List<ca_ConfigiDeal> Get_iDealConfig(String caller, Guid? prefixSA, Guid? codeCalen... | |
doc_23508940 | session['user'] = username
here aname and apass are username and password coming from database
A: I suggest creating a contextmanager to handle database session:
@contextmanager
def get_db_session(aname: str, apass: str):
connection = None
try:
connection = mysql.connector.connect(host='l... | |
doc_23508941 | Examples:
Start date: 08/01/2010
Frequency: Every 7 days
Occurrences: 4
End Date = 08/29/2010
Start date: 08/01/2010
Frequency: Every Month
Occurrences: 3
End Date = 11/01/2010
Some notes- Our server is running PHP 5.2.13 and Symfony 1.1. It's not a requirement that I use symfony to adjust the date, as long as I can ... | |
doc_23508942 | #Loading Libraries
library(RJSONIO)
library(RCurl)
library(httr)
library(jsonlite)
r <- POST(url,
body = '{
"id":104106,
"lookupName": "Task Report",
"filters": [
{
"name":"Created T... | |
doc_23508943 | I tried to use calc() a bit more, but since the contents of the element I want to centre may vary over time, I want to try and make it always be centred.
I am doing this with the following: margin: 0px calc(50% - 554px / 2) 0px calc(50% - 554px / 2);
The current width of the element is 554px. So dividing it by 2 and r... | |
doc_23508944 |
Very simple logic to create the above chart:
pivot_df = base_df.pivot(index='date', columns='column10', values='values')
pivot_df1 = pivot_df.fillna(0)
pivot_df1 = pivot_df1.astype(float)
pivot_df1 = pivot_df1.plot.bar(stacked=True, figsize=(10,7))
Now I am trying to create a line chart using the same base dataset (s... | |
doc_23508945 | In this case have a mergefield for PO_Box and Adress, if there is a PO_Box # use it, otherwise use the Standard Adress.
Example of the MailMerge what it would look like in Word:
{ IF { MERGEFIELD PO_Box } > "1" "{ MERGEFIELD PO_Box }" "{ MERGEFIELD Adress }" \* MERGEFORMAT }
Is there a way to make this happen thru som... | |
doc_23508946 | This the question
This work is based on operator overloading, you need to build a string calculator,
the calculator can do add and minus functions for string variables (there will be only
characters and space for the string).
The problem I ran into is when I try to add the two ve... | |
doc_23508947 | server {
listen 80;
server_name app.me.site;
return 308 https://$host$uri;
location .well-known {
root /var/www/.well-known;
try_files /$uri /$uri/ /index.html;
}
# other configs
}
The path is /var/www/app.
I also created /var/www/.well-known for Let's Encrypt and it is accessible but it's only acc... | |
doc_23508948 | When I compile and run the application in Debug mode, the models are textured and displayed properly. As soon as I debug the application or compile and run the application using release mode textures are no longer being applied to the models.
I have tracked down the problem to glGenTextures not giving me a valid name. ... | |
doc_23508949 | if !val! LSS 0 (
echo value is !val!
echo value is less than zero - SLA breached!
) else (
echo value is !val!
echo value is greater than zero - SLA not breached.
)
The values of !val! are:
-0.9513888888888888888888888888888888888889
63.067361111111111111111111111... | |
doc_23508950 |
A: You need to export the unity project as a library.
Check here https://docs.unity3d.com/Manual/UnityasaLibrary-Android.html
| |
doc_23508951 | C:\Program Files (x86)\Java\jdk1.7.0_80\bin>java -jar c:\conf\ords.war
Exception in thread "main" java.lang.UnsupportedClassVersionError: oracle/dbtool
s/jarcl/Entrypoint : Unsupported major.minor version 52.0
at java.lang.ClassLoader.defineClass1(Native Method)
at java.lang.ClassLoader.defineClass(Clas... | |
doc_23508952 | no|name|flag
------------
1|kumar|1
2|rajesh singh|1
3|adi sneedar|1
4|danielle castro|1
5|cef danish|1
if i did
select count(*) from tablename where name like '% %'
it will return 2 records.
if i did "multiple spaces", like 2 or more spaces
select count(*) from tablename where name like '% %'
it returns 0(this m... | |
doc_23508953 |
*
*Tried to install npm https://devblogs.microsoft.com/typescript/the-future-of-declaration-files-2/
and
Moment.js + TypeScript. Cannot find name moment
*VS 2017 Cannot find moment,JQueryPromise,JQueryEventObject & JQueryAjaxSettings
Suggested something but I don't get it.
A: I solved the problem. Do not use... | |
doc_23508954 | For the purpose of routing, I'm using angular-route.
I have added angular-route folder under node_modules folder like following:
All of sudden, my app started complaining about failed to parse sourcemap when it is in debugger mode like following Failed to parse SourceMap: http://localhost:3000/angular-route.min.js.ma... | |
doc_23508955 | Please help in that. If you did the same please sent it with sample screen.
A: I have created a sample flow with parallel flows where both receives error. I have created a variable and appended the errors of each of the flow to the string variable. Finally, I have sent the resultant string to email. Below is the flow ... | |
doc_23508956 | How can I fix this?
const URL = "https://api.rss2json.com/v1/api.json?rss_url= THE WEBSITE RSS FEED";
const PROXY = "https://api.allorigins.win/raw?url=";
let content = null;
const [feed, setFeed] = useState(null);
useEffect(() => {
axios.get(URL)
.then(response => {
setFeed(respon... | |
doc_23508957 | There are lots of different architectures for web applications which are to be implemented using Java. The answers to this question may serve as a library of various web application designs with their pros and cons. While I realize that the answers will be subjective, let's try to be as objective as we can and motivate... | |
doc_23508958 | I would like to create a new Dataframe by sampling a fixed number of samples such that the average age of the new DataFrame is the same as the original DataFrame.
sample_df = pd.DataFrame({'Var':['A','B','C','D','E'] , 'Ages' : [22,35,43,18,NaN]})
sample_df
Out[410]:
Var Ages
0 A 22
1 B 35
2 C 43
3 ... | |
doc_23508959 | Thanks everyone.
A: Create a separate Repository layer, access it only from your viewModels.
In this way you will have view/databinding triggering requests.
Next, have some State management inside Repository or store some data there(use LiveData)
In your ViewModel assign value to the ref of LiveData from repository. S... | |
doc_23508960 | I have two collections.
Collection 1
[{
"link": "http://example.com/posts/1",
"created_at": "2018-09-20 05:14:10",
"description": "some desc 1",
"post_id": 1,
"priority": "2",
"identifiedBy": "x",
},
{
"link": "http://example.com/posts/2",
"created_at": "2018-09-20 05:14:10",
"description": "some desc 2",
"post_id": 2... | |
doc_23508961 |
*
*On an up-to-date branch, I modify a tracked file. git status shows it as modified
*git stash (responds with "Saved working directory and index state WIP on...)
*git status still shows the file as modified, but git diff (and git gui) show no changes.
*git stash list shows the stash was created
*git stash pop r... | |
doc_23508962 | I want to register users (on my website) based on their device type and Assign a particular UId to each device.
So is it possible to detect Device type which is visiting my website and let them access services according to their device type?
Any JavaScript or jQuery way possible?
Please suggest.
A: This is the javascr... | |
doc_23508963 | Using a json API how would we update course to assign multiple students to a course
Model
class Course < ActiveRecord::Base
has_many :course_students
has_many :students, through: course_students
accepts_nested_attributes_for :course_students
end
class Student < ActiveRecord::Base
has_many :course_students
ha... | |
doc_23508964 | Thank you very much in advance.
A: One of the easiest alternatives is to start with an ARFF file for a two class problem like:
@relation corpus
@attribute text string
@attribute class {pos,neg}
@data
'long text with words ... ',pos
The text is represented as a String type and the class is a nominal with two valu... | |
doc_23508965 | Here's the scenario:
I have two account - accountA & accountB. Both of them are logged in. but as i could only show the desktop of one of them, I showed accountA. Then I open an terminal and ssh to accountB to run such a simple AppleScript
tell application "Finder"
activate
end tell
Then returns the error
test.scpt:... | |
doc_23508966 | $totalprice += $product['price'] * $product['count'];
and
$totalprice = $product['price'] * $product['count'];
both give the same result. so what's the use of (+=) ?
A: += is a shorthand for adding the result to the target. The first one is equivalent to:
$totalprice = $totalprice + ($product['price'] * $product['... | |
doc_23508967 | df1
id value
ba1 4
ba2 5
ba3 5
df2
id value
ba1, ba3 4
ba2 3
ba2, ba3 2
ba3 5
df3
id value
ba1, ba3 3
ba1, ba3, ba4 1
ba2 3
ba2, ba3 2
ba3 4
ba3, ba4 1
Every df has the same sum of value, 14. I think that would be a stacked bar plot good s... | |
doc_23508968 | This isn’t strictly a gridlayout like having loads of photos or items evenly split across a screen, but understanding more the sizes and locations I can add surfaces or views.
Grid layout http://www.pandafinity.com/Screen-Grid.jpg
The above image is how I want to view the screen – so I can layout various items, some wi... | |
doc_23508969 | Looking at the Firebug log, the following errors were being reported:
Blocked loading mixed active content "http://code.jquery.com/ui/1.8.10/themes/smoothness/jquery-ui.css"
Blocked loading mixed active content "http://ajax.aspnetcdn.com/ajax/jquery.ui/1.8.10/jquery-ui.min.js"`
among other errors caused by the latter ... | |
doc_23508970 | I already tried something like that below, but this seperates with normal commas:
Sub walrus()
Dim dir As String
dir = "My\Super\Cool\Path.csv"
Application.DisplayAlerts = False
ThisWorkbook.Sheets("FooBar").Copy
ActiveWorkbook.SaveAs Filename:=dir, FileFormat:=xlCSV, CreateBackup:=True
ActiveWorkbook.Close
Applica... | |
doc_23508971 | import java.awt.BorderLayout;
import java.awt.Dimension;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JScrollPan... | |
doc_23508972 | for publish in soup.find('ul', {'class': 'list-view real-estates'}).find_all('span', {'class': 're-offer-type'}):
publish_value = publish.get_text().strip()
publisher.append(publish_value)
I need to extract the agency that is offering the property (look at image):
The using the above code extract the data ver... | |
doc_23508973 | I'm trying to get the nested component to have a dynamic height connected to the vertical scrolling of the page, and by having two different background-color the container gets filled or emptied as the user scrolls up or down on the page.
import styled from 'styled-components';
export const DynamicScrollbarContainer =... | |
doc_23508974 |
$("*[id^=popout1]").on("click", function () {
//debugger;
$(".FakeClass").dropdown('toggle');
var id = this.getAttribute("data-id");
var reportType = $('#ReportExecutionType').val();
var url = '@Url.Action("PopUp", "Benchmark", new { cid = "_id_" , repo... | |
doc_23508975 | I have looked at several products. FileMaker is more or less the type of product I'm looking for, but it's not SQL-based. Informix 4GL and 4Js are what comes closest, but the lead time for customizing/debugging seems to take a long time.
A: See the feature list of Oracle Application Express for some good ideas.
A... | |
doc_23508976 | I tried style.configure() method, bootstyle attribute and all, still not working.
(PS: still very much of beginner in the field , so forgive me for my mistakes)
from tkinter import *
from tkinter import ttk
import mysql.connector
from datetime import date
import ttkbootstrap as tb
def custview():
temp = tb.Window(... | |
doc_23508977 | class DataTag(models.Model):
title = models.CharField(max_length=120, unique=True)
relations = models.ManyToManyField('DataTag',
related_name='related_data_tags', blank=True)
and the another class is:
class Data(models.Model):
tags = models.ManyToManyField('DataTag',related_name = 'data')
def tag_name(self):
... | |
doc_23508978 | one for summation-substraction
other for displaying total value
the main activity contains variable (total)
if in fragment the value is sum then variable (total) is increased by entered value otherwise it is decreased by entered value
and this variable (total) is displayed in second fragment
A: you can use interface ... | |
doc_23508979 | In my tests, I am finding that even in the simple case of trying to download a file when supplying a url that points to a page-not-found (error 404) address, downloads.download() will happily download "a file" and resolve the promise with no error. The downloadItem's status will show "completed," the file will be shown... | |
doc_23508980 | My question is why the result would be correct without __syncthreads().
__global__ void dot( int *a, int *b, int *c, int *dot ){
int tid = threadIdx.x;
int i;
c[tid] = a[tid] * b[tid];
//__syncthreads();
//need synchronize??
if(tid==0){
for(i=0; i<N; i++){
*dot += c[i]... | |
doc_23508981 | My code:
JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
DiagnosticCollector<JavaFileObject> diagnostics = new DiagnosticCollector<JavaFileObject>();
CompilationTask task = compiler.getTask(null, null, diagnostics, null, null, prepareFile(nazwa, content));
task.call();
List<String> retur... | |
doc_23508982 | So far I've been successful: I can open any program under the open -a or open -b fashion, and support optionally waiting. I'm using NSTask for that purpose.
However, I'd like to be able to open documents too. As far as I can see, you need to use NSWorkspace for that, but using NSWorkspace to launch programs results in ... | |
doc_23508983 |
Write a function that recives two pointers to strings, checks if they have the same letter and if does, it will return a pointer to the letter found in the first string.
How can I write this function?
I wrote this and it's not working:
char *checkSameChr(char *str1, char *str2)
{
while (*str1)
{
whil... | |
doc_23508984 | So my first question is why is that smaller?
My second question is, how can I add users to the database using the Administration tool?
It is still adding them to the default ASPNETDB.
Thanks.
update
ok i figured out the second question. you need to change the default provider in web.config.
http://eashi.wordpress.com/... | |
doc_23508985 | For example I want to open the folderA that is on pcA from my PC and get all the images in
that folder and display them in my site. Is this possible?
Here is my code:
$dir1 = "pictures/";
$dir2 = "pictures2/";
$dir3 = "pictures3/";
$basedir = array(
'basedir1' => $dir1 ,
'basedir2' => $dir2 ,
'basedir3' ... | |
doc_23508986 | I've got a script that's using .on() because an element is dynamically generated, and it isn't working. Just to test it out, I replaced the selector with the dynamic element's wrap, which is static, and it still didn't work! When I switched to plain old .click for the wrap it worked, though.
(This just won't work for... | |
doc_23508987 |
A: I'm not sure what your exact end goal is but I suspect the serial directive is what you're looking for to limit how the execution operates. Keep in mind you may have to split into multiple plays within the playbook depending on how you have things setup now.
http://docs.ansible.com/ansible/latest/playbooks_delegati... | |
doc_23508988 | /abhyudaya-cooperative-bank.html and
similarly
http://example.com/index.php?Bank=abhyudaya-cooperative-bank&State=gujarat has to be rewritten and redirected to
http://example.com/abhyudaya-cooperative-bank/gujarat.html
i know it can be done through .htacces file. i m not getting how to do it.
please help me. thank you... | |
doc_23508989 | In below implementation, as the value of key is already moved, how can we query the value from the store again with the given key?
Is there a better way to write this code when key does not implement the clone trait?
struct Cacher<T, Y>
where
T: Fn(&Y) -> Y,
Y: Eq + Hash,
{
store: HashMap<Y, Y>,
compute... | |
doc_23508990 | I have defined a class called Profile.
# code in myapp/models/profile.py
from django.db import models
from django.contrib.auth.models import User
class Profile(models.Model):
user = models.OneToOneField(User)
field = models.CharField(max_length=30)
class Meta:
app_label="myapp"... | |
doc_23508991 | Array
(
[0] => stdClass Object
(
[item1] => foo 0
[item2] => bar 0
[catid] => 3
)
[1] => stdClass Object
(
[item1] => foo 1
[item2] => bar 1
[catid] => 7
)
[2] => stdClass Object
(
[... | |
doc_23508992 | using System.Web.Http.SelfHost;
using System.Web.Http;
using System.Net.Http;
namespace ASPNETWebAPISelfHost
{
class Program
{
static void Main(string[] args)
{
var config =
new HttpSelfHostConfiguration("http://localhost:8999");
config.Routes.MapHttpRoute("... | |
doc_23508993 | For example, I want to copy :
echo "some text file" >> file.txt
but i want to copy some text file to line 5 of file.txt.
A: Replace line number 5
sed '5s/.*/This is line 5/' file
Insert a string before line 5
sed '5i This is Line 4' file
Append a string after line 5
sed '5a This is Line 6' file
A: sed -i '4a\so... | |
doc_23508994 | products= [
%{
"id" => "7",
"use_count" => 1,
"name" => "A",
"price" => "$1",
"base_count" => 2
},
%{
"id" => "8",
"use_count" => 0,
"name" => "B",
"price" => "$14",
"base_count" => 0
},
%{
"id" => "9",
"use_count" => 1,
"name" => "C",
"price" => "$29",
... | |
doc_23508995 | val dbo = MongoDBObject("id" -> "0001", "name" -> "Kevin", "age" -> "100")
val json: JsValue = Json.parse(dbo.toString)
I tried to insert json via:
val obj = MongoDBObject("key" -> json)
collection.insert(obj)
However, there are many brackets [ and ] added to the json part when I do a db.collection.findOne() from th... | |
doc_23508996 | class ViewController: UIViewController {
var points = 0
@IBAction func action(_ sender: AnyObject) {
var firstTimePressed : Bool = false
if(firstTimePressed == false) {
firstTimePressed = true
}
else {
points += 0
}
}
}
A: In addition to th... | |
doc_23508997 | Timestamp is a UNIX timestamp. Category is an emotion word. Value is a numeric value.
Here's my code:
foreach ($twitromney['timestamp']) {
echo $twitromney['timestamp']['value'];
}
Now, this should display the value per timestamp, right? This is how ONE of the arrays looks (the object has hundreds of these):
Array (... | |
doc_23508998 | #rm(list=ls())
library(deSolve)
set.seed(1) # for reproducibility
t = seq(0,2*pi,by=2*pi/50) # sampling times
alpha = 1; beta = 1; sigma = 0.05 # test parameters
x = beta/alpha*(1-exp(-alpha*t))+rnorm(length(t),sd=sigma) # signal
D = data.frame(t=t,x=x)
plot(x~t,D,xlim=c(0,2*pi),ylim=c(0,1.2))
dxdt = function(t,x,p)... | |
doc_23508999 | However, suppose I have a small program written in the language X . How can I generate an EMF model instance for this program? To be more precise, I want a function, to which, I give the program file(say HelloWorld.X) as an argument and it returns the emf model for that program. What I have done so far is that I have w... |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.